@@ -28,6 +28,7 @@
 
 #include "winaspi.h"
 #include "ScsiIf.h"
+#include "log.h"
 #include "util.h"
 
 #include "decodeSense.cc"
@@ -118,7 +119,7 @@ int ScsiIf::init()
 
   if (!impl_->hinstlib)
   {
-     message (-2, "Can't load WNASPI32.DLL");
+     log_message(-2, "Can't load WNASPI32.DLL");
      return 1;
   }
   else {
@@ -166,7 +167,7 @@ int ScsiIf::sendCmd (const unsigned char *cmd,     int cmdLen,
               if (dataOut && dataOutLen)
               {
                  impl_->cmd6_.SRB_Flags      = SRBF_WRITE;
-                 impl_->cmd6_.SRB_BufPointer = dataOut;
+                 impl_->cmd6_.SRB_BufPointer = (BYTE*)dataOut;
                  impl_->cmd6_.SRB_BufLen     = dataOutLen;
               }
               else
@@ -213,7 +214,7 @@ int ScsiIf::sendCmd (const unsigned char *cmd,     int cmdLen,
               if (dataOut && dataOutLen)
               {
                  impl_->cmd10_.SRB_Flags      = SRBF_WRITE;
-                 impl_->cmd10_.SRB_BufPointer = dataOut;
+                 impl_->cmd10_.SRB_BufPointer = (BYTE*)dataOut;
                  impl_->cmd10_.SRB_BufLen     = dataOutLen;
               }
               else
@@ -262,7 +263,7 @@ int ScsiIf::sendCmd (const unsigned char *cmd,     int cmdLen,
               if (dataOut && dataOutLen)
               {
                  impl_->cmd12_.SRB_Flags      = SRBF_WRITE;
-                 impl_->cmd12_.SRB_BufPointer = dataOut;
+                 impl_->cmd12_.SRB_BufPointer = (BYTE*)dataOut;
                  impl_->cmd12_.SRB_BufLen     = dataOutLen;
               }
               else
@@ -327,7 +328,7 @@ int ScsiIf::inquiry()
   cmd[5] = 0;
 
   if (sendCmd (cmd, 6, NULL, 0, result, 0x2c, 1) != 0) {
-    message (-2, "Inquiry command failed on '%s': ", impl_->dev_);
+    log_message(-2, "Inquiry command failed on '%s': ", impl_->dev_);
     return 1;
   }
 
