@@ -1,8 +1,8 @@
 #define	USE_REMOTE
-/* @(#)scsi-remote.c	1.15 04/01/15 Copyright 1990,2000-2003 J. Schilling */
+/* @(#)scsi-remote.c	1.16 04/08/24 Copyright 1990,2000-2003 J. Schilling */
 #ifndef lint
 static	char __sccsid[] =
-	"@(#)scsi-remote.c	1.15 04/01/15 Copyright 1990,2000-2003 J. Schilling";
+	"@(#)scsi-remote.c	1.16 04/08/24 Copyright 1990,2000-2003 J. Schilling";
 #endif
 /*
  *	Remote SCSI user level command transport routines
@@ -94,7 +94,7 @@ static	char __sccsid[] =
 /*extern	BOOL	debug;*/
 LOCAL	BOOL	debug = 1;
 
-LOCAL	char	_scg_trans_version[] = "remote-1.15";	/* The version for remote SCSI	*/
+LOCAL	char	_scg_trans_version[] = "remote-1.16";	/* The version for remote SCSI	*/
 LOCAL	char	_scg_auth_schily[]	= "schily";	/* The author for this module	*/
 
 LOCAL	int	scgo_rsend		__PR((SCSI *scgp));
@@ -1078,6 +1078,13 @@ _rcmdrsh(ahost, inport, locuser, remuser, cmd, rsh)
 			_exit(EX_BAD);
 			/* NOTREACHED */
 		}
+		if (getuid() != geteuid() &&
+		    seteuid(pw->pw_uid) == -1) {
+			errmsg("seteuid(%lld) failed.\n",
+							(Llong)pw->pw_uid);
+			_exit(EX_BAD);
+			/* NOTREACHED */
+		}
 
 		/*
 		 * Fork again to completely detach from parent
