@@ -87,6 +87,7 @@ static	char __sccsid[] =
 #endif
 
 #include "scsi/sg.h"
+#include "oexcl.h"
 
 #undef sense			/* conflict in struct cdrom_generic_command */
 #include <linux/cdrom.h>
@@ -102,7 +103,7 @@ static	char __sccsid[] =
  *	Choose your name instead of "schily" and make clear that the version
  *	string is related to a modified source.
  */
-LOCAL	char	_scg_trans_version[] = "scsi-linux-sg.c-1.83";	/* The version for this transport*/
+LOCAL	char	_scg_trans_version[] = "scsi-linux-sg.c-1.83-RH";	/* The version for this transport*/
 
 #ifndef	SCSI_IOCTL_GET_BUS_NUMBER
 #define	SCSI_IOCTL_GET_BUS_NUMBER 0x5386
@@ -255,7 +256,7 @@ scgo_version(scgp, what)
 		 * return "schily" for the SCG_AUTHOR request.
 		 */
 		case SCG_AUTHOR:
-			return (_scg_auth_schily);
+			return ("schily - Red Hat");
 		case SCG_SCCS_ID:
 			return (__sccsid);
 		case SCG_KVERSION:
@@ -326,6 +327,10 @@ scgo_open(scgp, device)
 	if (device != NULL && *device != '\0') {
 #ifdef	USE_ATA
 		if (strncmp(device, "ATAPI", 5) == 0) {
+			if (scgp->overbose) {
+				js_fprintf((FILE *)scgp->errfile,
+				"Use of ATA is preferred over ATAPI.\n");
+			}
 			scgp->ops = &ata_ops;
 			return (SCGO_OPEN(scgp, device));
 		}
@@ -347,18 +352,6 @@ scgo_open(scgp, device)
 			 */
 			use_ata = TRUE;
 			device = NULL;
-			if (scgp->overbose) {
-				/*
-				 * I strongly encourage people who believe that
-				 * they need to patch this message away to read
-				 * the messages in the Solaris USCSI libscg
-				 * layer instead of wetting their tissues while
-				 * being unwilling to look besides their
-				 * own belly button.
-				 */
-				js_fprintf((FILE *)scgp->errfile,
-				"Warning: Using badly designed ATAPI via /dev/hd* interface.\n");
-			}
 		}
 	}
 
@@ -454,6 +447,7 @@ scanopen:
 		glob("/dev/scd[0-9][0-9]", GLOB_NOSORT|GLOB_APPEND, NULL, &globbuf);
 		glob("/dev/sg[a-z]", GLOB_NOSORT|GLOB_APPEND, NULL, &globbuf);
 		glob("/dev/sg[0-9]", GLOB_NOSORT|GLOB_APPEND, NULL, &globbuf);
+		glob("/dev/sr[0-9]", GLOB_NOSORT|GLOB_APPEND, NULL, &globbuf);
 		
 		for (i = 0; globbuf.gl_pathv && globbuf.gl_pathv[i] != NULL ; i++) {
 			devname = globbuf.gl_pathv[i];
@@ -467,13 +461,6 @@ scanopen:
 				if (scgp->errstr)
 					js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
 						    "Cannot open '/dev/scd*'");
-				if (errno != ENOENT && errno != ENXIO && errno != ENODEV && errno != EROFS) {
-					if (scgp->errstr)
-						js_snprintf(scgp->errstr, SCSI_ERRSTR_SIZE,
-							    "Cannot open '%s'", devname);
-					globfree(&globbuf);
-					return (0);
-				}
 			} else {
 				sg_clearnblock(f);	/* Be very proper about this */
 				if (sg_setup(scgp, f, busno, tgt, tlun, -1)) {
@@ -497,21 +484,8 @@ openbydev:
 			if (b < 0 || b > 25)
 				b = -1;
 		}
-		if (scgp->overbose) {
-			/*
-			 * Before you patch this away, are you sure that you
-			 * know what you are going to to?
-			 *
-			 * Note that this is a warning that helps users from
-			 * cdda2wav, mkisofs and other programs (that
-			 * distinguish SCSI addresses from file names) from
-			 * getting unexpected results.
-			 */
-			js_fprintf((FILE *)scgp->errfile,
-			"Warning: Open by 'devname' is unintentional and not supported.\n");
-		}
-					/* O_NONBLOCK is dangerous */
-		f = open(device, O_RDWR | O_NONBLOCK);
+		/* O_NONBLOCK is dangerous */
+		f = openexcl(device, O_RDWR | O_NONBLOCK);
 /*		if (f < 0 && errno == ENOENT)*/
 /*			goto openpg;*/
 
