@@ -1,4 +1,4 @@
-/* @(#)filereopen64.c	1.6 03/06/15 Copyright 2000-2003 J. Schilling */
+/* @(#)filereopen64.c	1.7 04/08/08 Copyright 2000-2003 J. Schilling */
 /*
  *	Copyright (c) 2000-2003 J. Schilling
  */
@@ -20,7 +20,7 @@
 
 #define	USE_LARGEFILES
 
-#include "io.h"
+#include "schilyio.h"
 
 #ifdef	HAVE_LARGEFILES
 
