@@ -1,4 +1,4 @@
-/* @(#)fpipe.c	1.11 03/06/15 Copyright 1986, 1995-2003 J. Schilling */
+/* @(#)fpipe.c	1.12 04/08/08 Copyright 1986, 1995-2003 J. Schilling */
 /*
  *	Copyright (c) 1986, 1995-2003 J. Schilling
  */
@@ -18,7 +18,7 @@
  * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "io.h"
+#include "schilyio.h"
 
 EXPORT int
 fpipe(pipef)
