@@ -1,4 +1,4 @@
-/* @(#)niwrite.c	1.4 03/09/23 Copyright 1986, 2001-2003 J. Schilling */
+/* @(#)niwrite.c	1.5 04/08/08 Copyright 1986, 2001-2003 J. Schilling */
 /*
  *	Non interruptable write
  *
@@ -20,7 +20,7 @@
  * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "io.h"
+#include "schilyio.h"
 #include <errno.h>
 
 EXPORT int
