@@ -37,12 +37,14 @@
 #include "guiUpdate.h"
 #include "ProgressDialog.h"
 #include "Settings.h"
+#include "ConfigManager.h"
 
 #include "config.h"
 #include "remote.h"
 #include "ScsiIf.h"
 #include "CdrDriver.h"
 #include "util.h"
+#include "log.h"
 #include "Toc.h"
 
 #define DRIVER_IDS 13
@@ -50,7 +52,7 @@
 
 CdDevice *CdDevice::DEVICE_LIST_ = NULL;
 
-char *CdDevice::DRIVER_NAMES_[DRIVER_IDS] = {
+const char *CdDevice::DRIVER_NAMES_[DRIVER_IDS] = {
   "Undefined",
   "cdd2600",
   "generic-mmc",
@@ -316,7 +318,7 @@ bool CdDevice::updateProgress(Glib::IOCondition cond, int fd)
       }
     }
     else {
-      message(-1, _("Reading of progress message failed."));
+      log_message(-1, _("Reading of progress message failed."));
     }
   }
 
@@ -372,8 +374,8 @@ bool CdDevice::recordDao(Gtk::Window& parent, TocEdit *tocEdit, int simulate,
                         int multiSession, int speed, int eject, int reload,
                         int buffer, int overburn)
 {
-  char tocFileName[30];
-  char *args[30];
+  char* tocFileName;
+  const char *args[30];
   int n = 0;
   char devname[30];
   char drivername[50];
@@ -387,10 +389,19 @@ bool CdDevice::recordDao(Gtk::Window& parent, TocEdit *tocEdit, int simulate,
       || process_ != NULL)
     return false;
 
-  sprintf(tocFileName, "/tmp/gcdm.toc.XXXXXX");
+  // Create temporary toc file. Get temporary directory from
+  // ConfigManager, then append mkstemp template.
+  Glib::ustring tempdir =
+      configManager->client()->get_string("/apps/gcdmaster/temp_dir");
+  int length = tempdir.length();
+  tocFileName = (char*)alloca(length + 24);
+
+  strcpy(tocFileName, tempdir.c_str());
+  strcat(tocFileName, "/gcdm.toc.XXXXXX");
+
   int fd = mkstemp(tocFileName);
   if (!fd) {
-    message(-2, _("Cannot create temporary toc-file: %s"), strerror(errno));
+    log_message(-2, _("Cannot create temporary toc-file: %s"), strerror(errno));
     return false;
   }
 
@@ -399,7 +410,7 @@ bool CdDevice::recordDao(Gtk::Window& parent, TocEdit *tocEdit, int simulate,
   // translation, besides it's already been done).
   if (!tocEdit->toc()->write(fd, true)) {
     close(fd);
-    message(-2, _("Cannot write temporary toc-file."));
+    log_message(-2, _("Cannot write temporary toc-file."));
     return false;
   }
 
@@ -488,7 +499,6 @@ bool CdDevice::recordDao(Gtk::Window& parent, TocEdit *tocEdit, int simulate,
   }
   else {
     unlink(tocFileName);
-    free(tocFileName);
     return false;
   }
 }
@@ -529,7 +539,7 @@ void CdDevice::progress(int *status, int *totalTracks, int *track,
 int CdDevice::extractDao(Gtk::Window& parent, const char *tocFileName,
                          int correction, int readSubChanMode)
 {
-  char *args[30];
+  const char *args[30];
   int n = 0;
   char devname[30];
   char drivername[50];
@@ -640,7 +650,7 @@ int CdDevice::duplicateDao(Gtk::Window& parent, int simulate, int multiSession,
                            int onthefly, int correction, int readSubChanMode, 
 			   CdDevice *readdev)
 {
-  char *args[30];
+  const char *args[30];
   int n = 0;
   char devname[30];
   char drivername[50];
@@ -793,7 +803,7 @@ void CdDevice::abortDaoDuplication()
 int CdDevice::blank(Gtk::Window* parent, int fast, int speed, int eject,
                     int reload)
 {
-  char *args[20];
+  const char *args[20];
   int n = 0;
   char devname[30];
   char drivername[50];
@@ -938,7 +948,7 @@ const char *CdDevice::driverName(int id)
 
 const char *CdDevice::status2string(Status s)
 {
-  char *ret = NULL;
+  const char *ret = NULL;
 
   switch (s) {
   case DEV_READY:
@@ -975,7 +985,7 @@ const char *CdDevice::status2string(Status s)
 
 const char *CdDevice::deviceType2string(DeviceType t)
 {
-  char *ret = NULL;
+  const char *ret = NULL;
 
   switch (t) {
   case CD_R:
@@ -1028,37 +1038,34 @@ void CdDevice::importSettings()
  */
 void CdDevice::exportSettings()
 {
-  int i, n;
-  char *s;
-  char buf[20];
-  CdDevice *drun;
+  static const char* pathBase = "/apps/gcdmaster/devices";
+  char* key;
+  char* s;
+  CdDevice* drun;
+  int n;
 
-  gnome_config_clean_section(SET_SECTION_DEVICES);
+  key = (char*)alloca(strlen(pathBase) + 12);
 
   for (drun = first(), n = 0; drun != NULL; drun = next(drun)) {
+
     if (drun->manuallyConfigured()) {
+      sprintf(key, "%s%d", pathBase, n);
+      s = drun->settingString();
+
+      try {
+	Gnome::Conf::Schema sch;
+	sch.set_type(Gnome::Conf::VALUE_STRING);
+	configManager->client()->set(key, sch);
+	configManager->client()->set(key, s);
+      } catch (const Glib::Error& e) {
+	std::cerr << e.what() << std::endl;
+      }
+      // CdDevice::settingString allocates the string. Must delete it
+      // here.
+      delete[] s;
       n++;
     }
   }
-
-  if (n > 0) {
-    gnome_config_set_int(SET_DEVICES_NUM, n);
-
-    gnome_config_push_prefix(SET_SECTION_DEVICES);
-
-    for (drun = first(), i = 0; drun != NULL; drun = next(drun)) {
-      if (drun->manuallyConfigured()) {
-	sprintf(buf, "%d", i);
-	s = drun->settingString();
-	gnome_config_set_string(buf, s);
-	delete[] s;
-
-	i++;
-      }
-    }
-
-    gnome_config_pop_prefix();
-  }
 }
 
 CdDevice *CdDevice::add(const char* dev, const char *vendor,
