@@ -9,6 +9,7 @@ Gtk::StockID Icons::OPEN("gcdmaster-open");
 Gtk::StockID Icons::AUDIOCD("gcdmaster-audiocd");
 Gtk::StockID Icons::COPYCD("gcdmaster-copycd");
 Gtk::StockID Icons::DUMPCD("gcdmaster-dumpcd");
+Gtk::StockID Icons::RECORD("gcdmaster-record");
 
 struct Icons::IconEntry Icons::iconList[] = {
   { Icons::PLAY,      play_pixbuf },
@@ -18,7 +19,8 @@ struct Icons::IconEntry Icons::iconList[] = {
   { Icons::OPEN,      open_pixbuf },
   { Icons::AUDIOCD,   audiocd_pixbuf },
   { Icons::COPYCD,    copycd_pixbuf},
-  { Icons::DUMPCD,    dumpcd_pixbuf}
+  { Icons::DUMPCD,    dumpcd_pixbuf},
+  { Icons::RECORD,    record_pixbuf}
 };
 
 void Icons::registerStockIcons()
@@ -26,7 +28,7 @@ void Icons::registerStockIcons()
   Glib::RefPtr<Gtk::IconFactory> factory = Gtk::IconFactory::create();
   factory->add_default();
 
-  for (int i = 0; i < G_N_ELEMENTS(iconList); i++) {
+  for (unsigned i = 0; i < G_N_ELEMENTS(iconList); i++) {
     Gtk::IconSource* source = new Gtk::IconSource;
     Glib::RefPtr<Gdk::Pixbuf> pixbuf =
         Gdk::Pixbuf::create_from_inline(-1, iconList[i].pixbuf);
